@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 from functools import wraps
 from flask import request
-from pydantic import ValidationError
 
 __author__ = "Ahmed Nafies Okasha Mohamed <ahmed.nafies@gmail.com>"
 __copyright__ = "Copyright 2020, Ahmed Nafies Okasha Mohamed"
 __license__ = "MIT"
-__version__ = "0.1.0"
+__version__ = "1.0.0"
 
 
 BODY_METHODS = ["POST", "PUT", "PATCH"]
@@ -25,7 +24,6 @@ def validate(query, body):
 
     payload = None
     query_params = None
-
     if body and request.method not in BODY_METHODS:
         raise InvalidOperation(
             f"Http method '{request.method}' does not contain a payload,"
@@ -37,7 +35,6 @@ def validate(query, body):
     if query:
         params = request.args
         query_params = query(**params).dict()
-
     return dict(payload=payload, query=query_params)
 
 
@@ -45,10 +42,7 @@ def webargs(query=None, body=None):
     def decorator(f):
         @wraps(f)
         def decorated_function(*args, **kwargs):
-            try:
-                result = validate(query, body)
-            except ValidationError as e:
-                return str(e)
+            result = validate(query, body)
             kwargs.update(result)
             response = f(*args, **kwargs)
             return response
